<?php

require_once 'base/GepObservopersoliEntityBase.php';

/**
 * GepObseropersoliEntity.
 *
 * @package Entity
 * @author  tarcisiopereira <username@example.com>
 */
class GepObservopersoliEntity extends GepObservopersoliEntityBase
{


    /**
     * Retorna a observacao do operador da solicitacao.
     *
     * @param integer $nrorg      Numero da organizacao.
     * @param integer $nrsoli     Numero da solicitacao.
     * @param integer $nrparcoper Numero do operador da observacao.
     *
     * @return Ambigous <Ambigous, NULL, mixed>
     */
    public static function retornaObservOper($nrorg, $nrsoli, $nrparcoper){
        $dados = GepObservopersoli::buscaGepObservopersoli(
            $nrorg,
            $nrsoli,
            $nrparcoper
        );
        return $dados;
    }


    /**
     * Atualiza os registros de observacao do operador.
     *
     * @param integer $nrorg      Numero da organizacao.
     * @param integer $nrsoli     Numero da solicitacao.
     * @param integer $nrparcoper Numero do operador da observacao.
     * @param string  $observ     Observacao do operador.
     * @param string  $fonte      Configuracao da fonte da observacao.
     * @param integer $codigo     Cdigo da observacao.
     *
     * @return boolean
     */
    public static function modificaObservOper(
        $nrorg,
        $nrsoli,
        $nrparcoper,
        $observ,
        $fonte,
        $codigo
    )
    {
        $dados = GepObservopersoli::modificaGepObservopersoli(
            $nrorg,
            $nrsoli,
            $nrparcoper,
            $observ,
            $fonte,
            $codigo
        );
        return $dados;
    }


    /**
     * Insere os registros da tabela gep_observopersoli.
     *
     * @param integer $nrorg      Numero da organizacao.
     * @param integer $nrsoli     Numero da solicitacao.
     * @param integer $nrparcoper Numero do operador da observacao.
     * @param string  $observ     Observacao do operador.
     * @param string  $fonte      Configuracao da fonte da observacao.
     *
     * @return void
     */
    public static function insereObservOper(
        $nrorg,
        $nrsoli,
        $nrparcoper,
        $observ,
        $fonte
    )
    {
        $novocodigo = (int)Novocodigo::geraCodigo($nrorg, 'GEP_OBSERVOPERSOLI', 10);
        $obj = new self();
        $obj->setNrobservopersoli($novocodigo);
        $obj->setNrsolicitacao($nrsoli);
        $obj->setNrorg($nrorg);
        $obj->setNrparcoperador($nrparcoper);
        $obj->setTxobservopersoli($observ);
        $obj->setTxfonteobservoper($fonte);

        $obj->setDtinclusao(now());
        $obj->setDtultatu(now());

        $obj->persist();
    }


}

